Module: CemSpecHelper
- Defined in:
- lib/cem_spec_helper.rb,
lib/cem_spec_helper/version.rb,
lib/cem_spec_helper/mapping_data_spec.rb,
lib/cem_spec_helper/resource_data_spec.rb
Defined Under Namespace
Modules: MappingDataSpec, ResourceDataSpec
Constant Summary collapse
- VERSION =
'0.1.2'
Class Method Summary collapse
-
.included(base) ⇒ Object
Makes it so the CemSpecHelper module has to be included in the spec_helper.rb file.
Class Method Details
.included(base) ⇒ Object
Makes it so the CemSpecHelper module has to be included in the spec_helper.rb file.
5 6 7 8 9 10 11 12 13 14 15 16 |
# File 'lib/cem_spec_helper.rb', line 5 def self.included(base) require 'cem_spec_helper/mapping_data_spec' require 'cem_spec_helper/resource_data_spec' require 'cem_spec_helper/version' RSpec.configure do |config| config.include CemSpecHelper::MappingDataSpec config.extend CemSpecHelper::MappingDataSpec config.include CemSpecHelper::ResourceDataSpec config.extend CemSpecHelper::ResourceDataSpec end end |